@@ -19,7 +19,8 @@
 /* This is the gdm slave process. gdmslave runs the chooser, greeter
  * and the user's session scripts. */
 
-#include <config.h>
+#include "config.h"
+
 #include <unistd.h>
 #include <syslog.h>
 #include <grp.h>
