@@ -31,7 +31,7 @@
  * placed in the _gdm_set_value_string, _gdm_set_value_int, or
  * _gdm_set_value_bool functions.
  */
-#include <config.h>
+#include "config.h"
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -216,7 +216,7 @@ static gchar *GdmHosts;
 static gchar *GdmGraphicalThemeColor;
 static gchar *GdmGraphicalThemeDir;
 static gchar *GdmGraphicalThemes;
-static gchar *GdmPostDisplayProgram;
+static gchar *GdmPreFetchProgram;
 
 static gint GdmPositionX;
 static gint GdmPositionY;
@@ -495,8 +495,8 @@ gdm_config_init (void)
    gdm_config_add_hash (GDM_KEY_DEFAULT_HOST_IMG, &GdmHost, &string_type);
    gdm_config_add_hash (GDM_KEY_HOST_IMAGE_DIR, &GdmHostImageDir, &string_type);
    gdm_config_add_hash (GDM_KEY_HOSTS, &GdmHosts, &string_type);
-   gdm_config_add_hash (GDM_KEY_POST_DISPLAY_PROGRAM,
-      &GdmPostDisplayProgram, &string_type);
+   gdm_config_add_hash (GDM_KEY_PRE_FETCH_PROGRAM,
+      &GdmPreFetchProgram, &string_type);
 
    /* int values */
    gdm_config_add_hash (GDM_KEY_XINERAMA_SCREEN, &GdmXineramaScreen, &int_type);
